@@ -1,5 +1,5 @@
 package Git::ObjectStore;
-$Git::ObjectStore::VERSION = '0.004';
+$Git::ObjectStore::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -44,7 +44,11 @@ sub new
     my $repodir = $self->{'repodir'};
 
     if ( not -e $repodir . '/config' ) {
-        Git::Raw::Repository->init($repodir, 1);
+        if( $self->{'writer'} ) {
+            Git::Raw::Repository->init($repodir, 1);
+        } else {
+            croak($repodir . ' does not contain a bare Git repository');
+        }
     }
 
     my $repo = $self->{'repo'} = Git::Raw::Repository->open($repodir);
@@ -446,7 +450,7 @@ Git::ObjectStore - abstraction layer for Git::Raw and libgit2
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -513,9 +517,9 @@ filesystem and exhausting its inode pool.
 =head2 new(%args)
 
 Creates a new object. If F<repodir> is empty or does not exist, the
-method initializes a new bare Git repository. If multiple processes may
-call this method simultaneously, it is up to you to provide locking, so
-that the objects are created one at a time.
+method (in writer mode only) initializes a new bare Git repository. If
+multiple processes may call this method simultaneously, it is up to you
+to provide locking and prevent the race condition.
 
 Mandatory arguments:
 
@@ -570,7 +574,8 @@ as a scalar.
 
 =head2 file_exists($path)
 
-This method returns true if the given file extsis in the branch.
+This method returns true if the given file extsis in the branch. In
+reader mode, it also returns true if path is a directory name.
 
 =head2 current_commit_id()
 
